@@ -23,7 +23,8 @@ from Products.GenericSetup.tests.conformance import \
     ConformsToIFilesystemExporter
 from Products.GenericSetup.tests.conformance import \
     ConformsToIFilesystemImporter
-from Products.PluggableAuthService.tests.utils import _setUpDefaultTraversable
+
+from ...tests.utils import _setUpDefaultTraversable
 
 
 class _TestBase(BaseRegistryTests, ConformsToIFilesystemExporter,
