@@ -25,9 +25,8 @@ from OFS.ObjectManager import ObjectManager
 from zExceptions import Unauthorized
 from zope.interface import implementer
 
-from Products.PluggableAuthService.utils import directlyProvides
-
 from ..interfaces.plugins import INotCompetentPlugin
+from ..utils import directlyProvides
 from .conformance import IUserFolder_conformance
 
 
@@ -756,8 +755,7 @@ class PluggableAuthServiceTests(unittest.TestCase, IUserFolder_conformance,
 
         from AccessControl.users import UnrestrictedUser
 
-        from Products.PluggableAuthService import PluggableAuthService
-
+        from .. import PluggableAuthService
         from ..interfaces.plugins import IExtractionPlugin
 
         old_eu = PluggableAuthService.emergency_user
@@ -862,8 +860,7 @@ class PluggableAuthServiceTests(unittest.TestCase, IUserFolder_conformance,
 
         from AccessControl.users import UnrestrictedUser
 
-        from Products.PluggableAuthService import PluggableAuthService
-
+        from .. import PluggableAuthService
         from ..interfaces.plugins import IAuthenticationPlugin
         from ..interfaces.plugins import IExtractionPlugin
 
@@ -913,8 +910,7 @@ class PluggableAuthServiceTests(unittest.TestCase, IUserFolder_conformance,
 
         from AccessControl.users import UnrestrictedUser
 
-        from Products.PluggableAuthService import PluggableAuthService
-
+        from .. import PluggableAuthService
         from ..interfaces.plugins import IAuthenticationPlugin
         from ..interfaces.plugins import IExtractionPlugin
 
@@ -987,8 +983,7 @@ class PluggableAuthServiceTests(unittest.TestCase, IUserFolder_conformance,
 
         from AccessControl.users import UnrestrictedUser
 
-        from Products.PluggableAuthService import PluggableAuthService
-
+        from .. import PluggableAuthService
         from ..interfaces.plugins import IAuthenticationPlugin
         from ..interfaces.plugins import IExtractionPlugin
 
@@ -1403,7 +1398,7 @@ class PluggableAuthServiceTests(unittest.TestCase, IUserFolder_conformance,
 
         from AccessControl.users import UnrestrictedUser
 
-        from Products.PluggableAuthService import PluggableAuthService
+        from .. import PluggableAuthService
 
         old_eu = PluggableAuthService.emergency_user
 
